# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto',
  package='yandex.cloud.mdb.mongodb.v1.config',
  syntax='proto3',
  serialized_options=b'\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n>yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto\x12\"yandex.cloud.mdb.mongodb.v1.config\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xdd\x11\n\x1aMongodConfig6_0_enterprise\x12W\n\x07storage\x18\x01 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage\x12n\n\x13operation_profiling\x18\x02 \x01(\x0b\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling\x12S\n\x03net\x18\x03 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network\x12Y\n\x08security\x18\x04 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security\x12Z\n\taudit_log\x18\x05 \x01(\x0b\x32G.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog\x12\x62\n\rset_parameter\x18\x06 \x01(\x0b\x32K.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.SetParameter\x1a\xdb\x06\n\x07Storage\x12\x66\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32Q.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger\x12_\n\x07journal\x18\x02 \x01(\x0b\x32N.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.Journal\x1a\xba\x04\n\nWiredTiger\x12u\n\rengine_config\x18\x01 \x01(\x0b\x32^.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig\x12}\n\x11\x63ollection_config\x18\x02 \x01(\x0b\x32\x62.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xf0\x01\n\x10\x43ollectionConfig\x12\x87\x01\n\x10\x62lock_compressor\x18\x01 \x01(\x0e\x32m.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig.Compressor\"R\n\nCompressor\x12\x1a\n\x16\x43OMPRESSOR_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\n\n\x06SNAPPY\x10\x02\x12\x08\n\x04ZLIB\x10\x03\x12\x08\n\x04ZSTD\x10\x04\x1aJ\n\x07Journal\x12?\n\x0f\x63ommit_interval\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x31-500\x1a\xf7\x01\n\x12OperationProfiling\x12\x64\n\x04mode\x18\x01 \x01(\x0e\x32V.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\x1a\xad\x02\n\x08Security\x12\x35\n\x11\x65nable_encryption\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12Z\n\x04kmip\x18\x02 \x01(\x0b\x32L.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP\x1a\x8d\x01\n\x04KMIP\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12)\n\x04port\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tserver_ca\x18\x03 \x01(\t\x12\x1a\n\x12\x63lient_certificate\x18\x04 \x01(\t\x12\x16\n\x0ekey_identifier\x18\x05 \x01(\t\x1aU\n\x08\x41uditLog\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x39\n\x15runtime_configuration\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1aO\n\x0cSetParameter\x12?\n\x1b\x61udit_authorization_success\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xd9\x07\n\x1cMongoCfgConfig6_0_enterprise\x12Y\n\x07storage\x18\x01 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage\x12p\n\x13operation_profiling\x18\x02 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling\x12U\n\x03net\x18\x03 \x01(\x0b\x32H.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Network\x1a\xc0\x02\n\x07Storage\x12h\n\x0bwired_tiger\x18\x01 \x01(\x0b\x32S.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger\x1a\xca\x01\n\nWiredTiger\x12w\n\rengine_config\x18\x01 \x01(\x0b\x32`.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig\x1a\x43\n\x0c\x45ngineConfig\x12\x33\n\rcache_size_gb\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x1a\xf9\x01\n\x12OperationProfiling\x12\x66\n\x04mode\x18\x01 \x01(\x0e\x32X.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling.Mode\x12>\n\x11slow_op_threshold\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x06\xfa\xc7\x31\x02>0\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x07\n\x03OFF\x10\x01\x12\x0b\n\x07SLOW_OP\x10\x02\x12\x07\n\x03\x41LL\x10\x03\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xc9\x01\n\x1aMongosConfig6_0_enterprise\x12S\n\x03net\x18\x03 \x01(\x0b\x32\x46.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network\x1aV\n\x07Network\x12K\n\x18max_incoming_connections\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x31\x30-16384\"\xa6\x02\n\x1dMongodConfigSet6_0_enterprise\x12X\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\x12S\n\x0buser_config\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\x12V\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise\"\xae\x02\n\x1fMongoCfgConfigSet6_0_enterprise\x12Z\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12U\n\x0buser_config\x18\x02 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\x12X\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32@.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise\"\xa6\x02\n\x1dMongosConfigSet6_0_enterprise\x12X\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12S\n\x0buser_config\x18\x02 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise\x12V\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32>.yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterpriseBx\n&yandex.cloud.api.mdb.mongodb.v1.configZNgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1/config;mongodbb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])



_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR = _descriptor.EnumDescriptor(
  name='Compressor',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig.Compressor',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='COMPRESSOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SNAPPY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZLIB', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ZSTD', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1467,
  serialized_end=1549,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR)

_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1816,
  serialized_end=1875,
)
_sym_db.RegisterEnumDescriptor(_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE)

_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFF', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SLOW_OP', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALL', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1816,
  serialized_end=1875,
)
_sym_db.RegisterEnumDescriptor(_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE)


_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1306,
)

_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG = _descriptor.Descriptor(
  name='CollectionConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='block_compressor', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig.block_compressor', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1309,
  serialized_end=1549,
)

_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='collection_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.collection_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG, _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=979,
  serialized_end=1549,
)

_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL = _descriptor.Descriptor(
  name='Journal',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.Journal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='commit_interval', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.Journal.commit_interval', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0051-500', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1551,
  serialized_end=1625,
)

_MONGODCONFIG6_0_ENTERPRISE_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='journal', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.journal', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER, _MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=1625,
)

_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1628,
  serialized_end=1875,
)

_MONGODCONFIG6_0_ENTERPRISE_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=1963,
)

_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP = _descriptor.Descriptor(
  name='KMIP',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_name', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP.server_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP.port', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_ca', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP.server_ca', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_certificate', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP.client_certificate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_identifier', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP.key_identifier', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2126,
  serialized_end=2267,
)

_MONGODCONFIG6_0_ENTERPRISE_SECURITY = _descriptor.Descriptor(
  name='Security',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enable_encryption', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.enable_encryption', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kmip', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.kmip', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1966,
  serialized_end=2267,
)

_MONGODCONFIG6_0_ENTERPRISE_AUDITLOG = _descriptor.Descriptor(
  name='AuditLog',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog.filter', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='runtime_configuration', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog.runtime_configuration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2269,
  serialized_end=2354,
)

_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER = _descriptor.Descriptor(
  name='SetParameter',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.SetParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='audit_authorization_success', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.SetParameter.audit_authorization_success', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2356,
  serialized_end=2435,
)

_MONGODCONFIG6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongodConfig6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.security', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='audit_log', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.audit_log', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='set_parameter', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.set_parameter', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGODCONFIG6_0_ENTERPRISE_STORAGE, _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING, _MONGODCONFIG6_0_ENTERPRISE_NETWORK, _MONGODCONFIG6_0_ENTERPRISE_SECURITY, _MONGODCONFIG6_0_ENTERPRISE_AUDITLOG, _MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=2435,
)


_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG = _descriptor.Descriptor(
  name='EngineConfig',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cache_size_gb', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig.cache_size_gb', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1239,
  serialized_end=1306,
)

_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER = _descriptor.Descriptor(
  name='WiredTiger',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='engine_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.engine_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2881,
  serialized_end=3083,
)

_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE = _descriptor.Descriptor(
  name='Storage',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='wired_tiger', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.wired_tiger', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=3083,
)

_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING = _descriptor.Descriptor(
  name='OperationProfiling',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slow_op_threshold', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling.slow_op_threshold', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3086,
  serialized_end=3335,
)

_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=1963,
)

_MONGOCFGCONFIG6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongoCfgConfig6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.storage', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='operation_profiling', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.operation_profiling', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.net', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE, _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING, _MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2438,
  serialized_end=3423,
)


_MONGOSCONFIG6_0_ENTERPRISE_NETWORK = _descriptor.Descriptor(
  name='Network',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_incoming_connections', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network.max_incoming_connections', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\01010-16384', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1877,
  serialized_end=1963,
)

_MONGOSCONFIG6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongosConfig6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='net', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.net', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MONGOSCONFIG6_0_ENTERPRISE_NETWORK, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3426,
  serialized_end=3627,
)


_MONGODCONFIGSET6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongodConfigSet6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3630,
  serialized_end=3924,
)


_MONGOCFGCONFIGSET6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongoCfgConfigSet6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3927,
  serialized_end=4229,
)


_MONGOSCONFIGSET6_0_ENTERPRISE = _descriptor.Descriptor(
  name='MongosConfigSet6_0_enterprise',
  full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='effective_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise.effective_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise.user_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_config', full_name='yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise.default_config', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4232,
  serialized_end=4526,
)

_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG.fields_by_name['block_compressor'].enum_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG.containing_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG_COMPRESSOR.containing_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER.fields_by_name['collection_config'].message_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER.containing_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL.fields_by_name['commit_interval'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL.containing_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE
_MONGODCONFIG6_0_ENTERPRISE_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER
_MONGODCONFIG6_0_ENTERPRISE_STORAGE.fields_by_name['journal'].message_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL
_MONGODCONFIG6_0_ENTERPRISE_STORAGE.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE
_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE.containing_type = _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING
_MONGODCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG6_0_ENTERPRISE_NETWORK.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP.fields_by_name['port'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP.containing_type = _MONGODCONFIG6_0_ENTERPRISE_SECURITY
_MONGODCONFIG6_0_ENTERPRISE_SECURITY.fields_by_name['enable_encryption'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MONGODCONFIG6_0_ENTERPRISE_SECURITY.fields_by_name['kmip'].message_type = _MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP
_MONGODCONFIG6_0_ENTERPRISE_SECURITY.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE_AUDITLOG.fields_by_name['runtime_configuration'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MONGODCONFIG6_0_ENTERPRISE_AUDITLOG.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER.fields_by_name['audit_authorization_success'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER.containing_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['storage'].message_type = _MONGODCONFIG6_0_ENTERPRISE_STORAGE
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['operation_profiling'].message_type = _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['net'].message_type = _MONGODCONFIG6_0_ENTERPRISE_NETWORK
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['security'].message_type = _MONGODCONFIG6_0_ENTERPRISE_SECURITY
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['audit_log'].message_type = _MONGODCONFIG6_0_ENTERPRISE_AUDITLOG
_MONGODCONFIG6_0_ENTERPRISE.fields_by_name['set_parameter'].message_type = _MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG.fields_by_name['cache_size_gb'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER.fields_by_name['engine_config'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE.fields_by_name['wired_tiger'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER
_MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['mode'].enum_type = _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE
_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['slow_op_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING_MODE.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING
_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK.containing_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIG6_0_ENTERPRISE.fields_by_name['storage'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE
_MONGOCFGCONFIG6_0_ENTERPRISE.fields_by_name['operation_profiling'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING
_MONGOCFGCONFIG6_0_ENTERPRISE.fields_by_name['net'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK
_MONGOSCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_MONGOSCONFIG6_0_ENTERPRISE_NETWORK.containing_type = _MONGOSCONFIG6_0_ENTERPRISE
_MONGOSCONFIG6_0_ENTERPRISE.fields_by_name['net'].message_type = _MONGOSCONFIG6_0_ENTERPRISE_NETWORK
_MONGODCONFIGSET6_0_ENTERPRISE.fields_by_name['effective_config'].message_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIGSET6_0_ENTERPRISE.fields_by_name['user_config'].message_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGODCONFIGSET6_0_ENTERPRISE.fields_by_name['default_config'].message_type = _MONGODCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIGSET6_0_ENTERPRISE.fields_by_name['effective_config'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIGSET6_0_ENTERPRISE.fields_by_name['user_config'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOCFGCONFIGSET6_0_ENTERPRISE.fields_by_name['default_config'].message_type = _MONGOCFGCONFIG6_0_ENTERPRISE
_MONGOSCONFIGSET6_0_ENTERPRISE.fields_by_name['effective_config'].message_type = _MONGOSCONFIG6_0_ENTERPRISE
_MONGOSCONFIGSET6_0_ENTERPRISE.fields_by_name['user_config'].message_type = _MONGOSCONFIG6_0_ENTERPRISE
_MONGOSCONFIGSET6_0_ENTERPRISE.fields_by_name['default_config'].message_type = _MONGOSCONFIG6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongodConfig6_0_enterprise'] = _MONGODCONFIG6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongoCfgConfig6_0_enterprise'] = _MONGOCFGCONFIG6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongosConfig6_0_enterprise'] = _MONGOSCONFIG6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongodConfigSet6_0_enterprise'] = _MONGODCONFIGSET6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongoCfgConfigSet6_0_enterprise'] = _MONGOCFGCONFIGSET6_0_ENTERPRISE
DESCRIPTOR.message_types_by_name['MongosConfigSet6_0_enterprise'] = _MONGOSCONFIGSET6_0_ENTERPRISE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MongodConfig6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongodConfig6_0_enterprise', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig)
        })
      ,

      'CollectionConfig' : _reflection.GeneratedProtocolMessageType('CollectionConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_COLLECTIONCONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig)
        })
      ,
      'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.WiredTiger)
      })
    ,

    'Journal' : _reflection.GeneratedProtocolMessageType('Journal', (_message.Message,), {
      'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage.Journal)
      })
    ,
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Network)
    })
  ,

  'Security' : _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {

    'KMIP' : _reflection.GeneratedProtocolMessageType('KMIP', (_message.Message,), {
      'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_SECURITY_KMIP,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security.KMIP)
      })
    ,
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_SECURITY,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.Security)
    })
  ,

  'AuditLog' : _reflection.GeneratedProtocolMessageType('AuditLog', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_AUDITLOG,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.AuditLog)
    })
  ,

  'SetParameter' : _reflection.GeneratedProtocolMessageType('SetParameter', (_message.Message,), {
    'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE_SETPARAMETER,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise.SetParameter)
    })
  ,
  'DESCRIPTOR' : _MONGODCONFIG6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfig6_0_enterprise)
  })
_sym_db.RegisterMessage(MongodConfig6_0_enterprise)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Storage)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Storage.WiredTiger)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Storage.WiredTiger.CollectionConfig)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Storage.Journal)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.OperationProfiling)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Network)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Security)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.Security.KMIP)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.AuditLog)
_sym_db.RegisterMessage(MongodConfig6_0_enterprise.SetParameter)

MongoCfgConfig6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongoCfgConfig6_0_enterprise', (_message.Message,), {

  'Storage' : _reflection.GeneratedProtocolMessageType('Storage', (_message.Message,), {

    'WiredTiger' : _reflection.GeneratedProtocolMessageType('WiredTiger', (_message.Message,), {

      'EngineConfig' : _reflection.GeneratedProtocolMessageType('EngineConfig', (_message.Message,), {
        'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER_ENGINECONFIG,
        '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
        # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig)
        })
      ,
      'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE_WIREDTIGER,
      '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
      # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage.WiredTiger)
      })
    ,
    'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE_STORAGE,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Storage)
    })
  ,

  'OperationProfiling' : _reflection.GeneratedProtocolMessageType('OperationProfiling', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.OperationProfiling)
    })
  ,

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOCFGCONFIG6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfig6_0_enterprise)
  })
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise)
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise.Storage)
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise.Storage.WiredTiger)
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise.Storage.WiredTiger.EngineConfig)
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise.OperationProfiling)
_sym_db.RegisterMessage(MongoCfgConfig6_0_enterprise.Network)

MongosConfig6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongosConfig6_0_enterprise', (_message.Message,), {

  'Network' : _reflection.GeneratedProtocolMessageType('Network', (_message.Message,), {
    'DESCRIPTOR' : _MONGOSCONFIG6_0_ENTERPRISE_NETWORK,
    '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise.Network)
    })
  ,
  'DESCRIPTOR' : _MONGOSCONFIG6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfig6_0_enterprise)
  })
_sym_db.RegisterMessage(MongosConfig6_0_enterprise)
_sym_db.RegisterMessage(MongosConfig6_0_enterprise.Network)

MongodConfigSet6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongodConfigSet6_0_enterprise', (_message.Message,), {
  'DESCRIPTOR' : _MONGODCONFIGSET6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise)
  })
_sym_db.RegisterMessage(MongodConfigSet6_0_enterprise)

MongoCfgConfigSet6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongoCfgConfigSet6_0_enterprise', (_message.Message,), {
  'DESCRIPTOR' : _MONGOCFGCONFIGSET6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise)
  })
_sym_db.RegisterMessage(MongoCfgConfigSet6_0_enterprise)

MongosConfigSet6_0_enterprise = _reflection.GeneratedProtocolMessageType('MongosConfigSet6_0_enterprise', (_message.Message,), {
  'DESCRIPTOR' : _MONGOSCONFIGSET6_0_ENTERPRISE,
  '__module__' : 'yandex.cloud.mdb.mongodb.v1.config.mongodb6_0_enterprise_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise)
  })
_sym_db.RegisterMessage(MongosConfigSet6_0_enterprise)


DESCRIPTOR._options = None
_MONGODCONFIG6_0_ENTERPRISE_STORAGE_JOURNAL.fields_by_name['commit_interval']._options = None
_MONGODCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGODCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOCFGCONFIG6_0_ENTERPRISE_OPERATIONPROFILING.fields_by_name['slow_op_threshold']._options = None
_MONGOCFGCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections']._options = None
_MONGOSCONFIG6_0_ENTERPRISE_NETWORK.fields_by_name['max_incoming_connections']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.containerregistry.v1 import image_pb2 as yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/containerregistry/v1/image_service.proto',
  package='yandex.cloud.containerregistry.v1',
  syntax='proto3',
  serialized_options=b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n5yandex/cloud/containerregistry/v1/image_service.proto\x12!yandex.cloud.containerregistry.v1\x1a yandex/cloud/api/operation.proto\x1a-yandex/cloud/containerregistry/v1/image.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\x1cgoogle/api/annotations.proto\"\xa4\x02\n\x11ListImagesRequest\x12\x1d\n\x0bregistry_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\\\n\x0frepository_name\x18\x02 \x01(\tBC\xf2\xc7\x31?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*\x12\x1b\n\tfolder_id\x18\x07 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x05 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1b\n\x08order_by\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=100\"g\n\x12ListImagesResponse\x12\x38\n\x06images\x18\x01 \x03(\x0b\x32(.yandex.cloud.containerregistry.v1.Image\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"1\n\x0fGetImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"4\n\x12\x44\x65leteImageRequest\x12\x1e\n\x08image_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\'\n\x13\x44\x65leteImageMetadata\x12\x10\n\x08image_id\x18\x01 \x01(\t2\x8a\x04\n\x0cImageService\x12\x9a\x01\n\x04List\x12\x34.yandex.cloud.containerregistry.v1.ListImagesRequest\x1a\x35.yandex.cloud.containerregistry.v1.ListImagesResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/container-registry/v1/images\x12\x95\x01\n\x03Get\x12\x32.yandex.cloud.containerregistry.v1.GetImageRequest\x1a(.yandex.cloud.containerregistry.v1.Image\"0\x82\xd3\xe4\x93\x02*\x12(/container-registry/v1/images/{image_id}\x12\xc4\x01\n\x06\x44\x65lete\x12\x35.yandex.cloud.containerregistry.v1.DeleteImageRequest\x1a!.yandex.cloud.operation.Operation\"`\x82\xd3\xe4\x93\x02**(/container-registry/v1/images/{image_id}\xb2\xd2*,\n\x13\x44\x65leteImageMetadata\x12\x15google.protobuf.EmptyB\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3'
  ,
  dependencies=[yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_LISTIMAGESREQUEST = _descriptor.Descriptor(
  name='ListImagesRequest',
  full_name='yandex.cloud.containerregistry.v1.ListImagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='registry_id', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.registry_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='repository_name', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.repository_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071?|[a-z0-9]+(?:[._-][a-z0-9]+)*(/([a-z0-9]+(?:[._-][a-z0-9]+)*))*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.folder_id', index=2,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.page_size', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.page_token', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.filter', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_by', full_name='yandex.cloud.containerregistry.v1.ListImagesRequest.order_by', index=6,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=567,
)


_LISTIMAGESRESPONSE = _descriptor.Descriptor(
  name='ListImagesResponse',
  full_name='yandex.cloud.containerregistry.v1.ListImagesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='images', full_name='yandex.cloud.containerregistry.v1.ListImagesResponse.images', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.containerregistry.v1.ListImagesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=569,
  serialized_end=672,
)


_GETIMAGEREQUEST = _descriptor.Descriptor(
  name='GetImageRequest',
  full_name='yandex.cloud.containerregistry.v1.GetImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.GetImageRequest.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=674,
  serialized_end=723,
)


_DELETEIMAGEREQUEST = _descriptor.Descriptor(
  name='DeleteImageRequest',
  full_name='yandex.cloud.containerregistry.v1.DeleteImageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.DeleteImageRequest.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=725,
  serialized_end=777,
)


_DELETEIMAGEMETADATA = _descriptor.Descriptor(
  name='DeleteImageMetadata',
  full_name='yandex.cloud.containerregistry.v1.DeleteImageMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.containerregistry.v1.DeleteImageMetadata.image_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=779,
  serialized_end=818,
)

_LISTIMAGESRESPONSE.fields_by_name['images'].message_type = yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2._IMAGE
DESCRIPTOR.message_types_by_name['ListImagesRequest'] = _LISTIMAGESREQUEST
DESCRIPTOR.message_types_by_name['ListImagesResponse'] = _LISTIMAGESRESPONSE
DESCRIPTOR.message_types_by_name['GetImageRequest'] = _GETIMAGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteImageRequest'] = _DELETEIMAGEREQUEST
DESCRIPTOR.message_types_by_name['DeleteImageMetadata'] = _DELETEIMAGEMETADATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListImagesRequest = _reflection.GeneratedProtocolMessageType('ListImagesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMAGESREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.image_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListImagesRequest)
  })
_sym_db.RegisterMessage(ListImagesRequest)

ListImagesResponse = _reflection.GeneratedProtocolMessageType('ListImagesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTIMAGESRESPONSE,
  '__module__' : 'yandex.cloud.containerregistry.v1.image_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.ListImagesResponse)
  })
_sym_db.RegisterMessage(ListImagesResponse)

GetImageRequest = _reflection.GeneratedProtocolMessageType('GetImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETIMAGEREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.image_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.GetImageRequest)
  })
_sym_db.RegisterMessage(GetImageRequest)

DeleteImageRequest = _reflection.GeneratedProtocolMessageType('DeleteImageRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIMAGEREQUEST,
  '__module__' : 'yandex.cloud.containerregistry.v1.image_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteImageRequest)
  })
_sym_db.RegisterMessage(DeleteImageRequest)

DeleteImageMetadata = _reflection.GeneratedProtocolMessageType('DeleteImageMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEIMAGEMETADATA,
  '__module__' : 'yandex.cloud.containerregistry.v1.image_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.containerregistry.v1.DeleteImageMetadata)
  })
_sym_db.RegisterMessage(DeleteImageMetadata)


DESCRIPTOR._options = None
_LISTIMAGESREQUEST.fields_by_name['registry_id']._options = None
_LISTIMAGESREQUEST.fields_by_name['repository_name']._options = None
_LISTIMAGESREQUEST.fields_by_name['folder_id']._options = None
_LISTIMAGESREQUEST.fields_by_name['page_size']._options = None
_LISTIMAGESREQUEST.fields_by_name['page_token']._options = None
_LISTIMAGESREQUEST.fields_by_name['filter']._options = None
_LISTIMAGESREQUEST.fields_by_name['order_by']._options = None
_GETIMAGEREQUEST.fields_by_name['image_id']._options = None
_DELETEIMAGEREQUEST.fields_by_name['image_id']._options = None

_IMAGESERVICE = _descriptor.ServiceDescriptor(
  name='ImageService',
  full_name='yandex.cloud.containerregistry.v1.ImageService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=821,
  serialized_end=1343,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.containerregistry.v1.ImageService.List',
    index=0,
    containing_service=None,
    input_type=_LISTIMAGESREQUEST,
    output_type=_LISTIMAGESRESPONSE,
    serialized_options=b'\202\323\344\223\002\037\022\035/container-registry/v1/images',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.containerregistry.v1.ImageService.Get',
    index=1,
    containing_service=None,
    input_type=_GETIMAGEREQUEST,
    output_type=yandex_dot_cloud_dot_containerregistry_dot_v1_dot_image__pb2._IMAGE,
    serialized_options=b'\202\323\344\223\002*\022(/container-registry/v1/images/{image_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.containerregistry.v1.ImageService.Delete',
    index=2,
    containing_service=None,
    input_type=_DELETEIMAGEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002**(/container-registry/v1/images/{image_id}\262\322*,\n\023DeleteImageMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IMAGESERVICE)

DESCRIPTOR.services_by_name['ImageService'] = _IMAGESERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.serverless.apigateway.websocket.v1 import connection_pb2 as yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto',
  package='yandex.cloud.serverless.apigateway.websocket.v1',
  syntax='proto3',
  serialized_options=b'\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocket',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nHyandex/cloud/serverless/apigateway/websocket/v1/connection_service.proto\x12/yandex.cloud.serverless.apigateway.websocket.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a@yandex/cloud/serverless/apigateway/websocket/v1/connection.proto\";\n\x14GetConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\xfc\x01\n\x17SendToConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1e\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x10\xe8\xc7\x31\x01\x8a\xc8\x31\x08<=131072\x12_\n\x04type\x18\x03 \x01(\x0e\x32Q.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.DataType\";\n\x08\x44\x61taType\x12\x19\n\x15\x44\x41TA_TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x42INARY\x10\x01\x12\x08\n\x04TEXT\x10\x02\"\x1a\n\x18SendToConnectionResponse\"8\n\x11\x44isconnectRequest\x12#\n\rconnection_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x14\n\x12\x44isconnectResponse2\x9a\x05\n\x11\x43onnectionService\x12\xc8\x01\n\x03Get\x12\x45.yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest\x1a;.yandex.cloud.serverless.apigateway.websocket.v1.Connection\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/apigateways/websocket/v1/connections/{connection_id}\x12\xe2\x01\n\x04Send\x12H.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest\x1aI.yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse\"E\x82\xd3\xe4\x93\x02?\":/apigateways/websocket/v1/connections/{connection_id}:send:\x01*\x12\xd4\x01\n\nDisconnect\x12\x42.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest\x1a\x43.yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse\"=\x82\xd3\xe4\x93\x02\x37*5/apigateways/websocket/v1/connections/{connection_id}B\x94\x01\n3yandex.cloud.api.serverless.apigateway.websocket.v1Z]github.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/websocket/v1;websocketb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2.DESCRIPTOR,])



_SENDTOCONNECTIONREQUEST_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.DataType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DATA_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TEXT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=507,
  serialized_end=566,
)
_sym_db.RegisterEnumDescriptor(_SENDTOCONNECTIONREQUEST_DATATYPE)


_GETCONNECTIONREQUEST = _descriptor.Descriptor(
  name='GetConnectionRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=252,
  serialized_end=311,
)


_SENDTOCONNECTIONREQUEST = _descriptor.Descriptor(
  name='SendToConnectionRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\010<=131072', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest.type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SENDTOCONNECTIONREQUEST_DATATYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=314,
  serialized_end=566,
)


_SENDTOCONNECTIONRESPONSE = _descriptor.Descriptor(
  name='SendToConnectionResponse',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=594,
)


_DISCONNECTREQUEST = _descriptor.Descriptor(
  name='DisconnectRequest',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest.connection_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=596,
  serialized_end=652,
)


_DISCONNECTRESPONSE = _descriptor.Descriptor(
  name='DisconnectResponse',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=654,
  serialized_end=674,
)

_SENDTOCONNECTIONREQUEST.fields_by_name['type'].enum_type = _SENDTOCONNECTIONREQUEST_DATATYPE
_SENDTOCONNECTIONREQUEST_DATATYPE.containing_type = _SENDTOCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetConnectionRequest'] = _GETCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['SendToConnectionRequest'] = _SENDTOCONNECTIONREQUEST
DESCRIPTOR.message_types_by_name['SendToConnectionResponse'] = _SENDTOCONNECTIONRESPONSE
DESCRIPTOR.message_types_by_name['DisconnectRequest'] = _DISCONNECTREQUEST
DESCRIPTOR.message_types_by_name['DisconnectResponse'] = _DISCONNECTRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetConnectionRequest = _reflection.GeneratedProtocolMessageType('GetConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONNECTIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.GetConnectionRequest)
  })
_sym_db.RegisterMessage(GetConnectionRequest)

SendToConnectionRequest = _reflection.GeneratedProtocolMessageType('SendToConnectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOCONNECTIONREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionRequest)
  })
_sym_db.RegisterMessage(SendToConnectionRequest)

SendToConnectionResponse = _reflection.GeneratedProtocolMessageType('SendToConnectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SENDTOCONNECTIONRESPONSE,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.SendToConnectionResponse)
  })
_sym_db.RegisterMessage(SendToConnectionResponse)

DisconnectRequest = _reflection.GeneratedProtocolMessageType('DisconnectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTREQUEST,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.DisconnectRequest)
  })
_sym_db.RegisterMessage(DisconnectRequest)

DisconnectResponse = _reflection.GeneratedProtocolMessageType('DisconnectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTRESPONSE,
  '__module__' : 'yandex.cloud.serverless.apigateway.websocket.v1.connection_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.serverless.apigateway.websocket.v1.DisconnectResponse)
  })
_sym_db.RegisterMessage(DisconnectResponse)


DESCRIPTOR._options = None
_GETCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_SENDTOCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
_SENDTOCONNECTIONREQUEST.fields_by_name['data']._options = None
_DISCONNECTREQUEST.fields_by_name['connection_id']._options = None

_CONNECTIONSERVICE = _descriptor.ServiceDescriptor(
  name='ConnectionService',
  full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=677,
  serialized_end=1343,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCONNECTIONREQUEST,
    output_type=yandex_dot_cloud_dot_serverless_dot_apigateway_dot_websocket_dot_v1_dot_connection__pb2._CONNECTION,
    serialized_options=b'\202\323\344\223\0027\0225/apigateways/websocket/v1/connections/{connection_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Send',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Send',
    index=1,
    containing_service=None,
    input_type=_SENDTOCONNECTIONREQUEST,
    output_type=_SENDTOCONNECTIONRESPONSE,
    serialized_options=b'\202\323\344\223\002?\":/apigateways/websocket/v1/connections/{connection_id}:send:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Disconnect',
    full_name='yandex.cloud.serverless.apigateway.websocket.v1.ConnectionService.Disconnect',
    index=2,
    containing_service=None,
    input_type=_DISCONNECTREQUEST,
    output_type=_DISCONNECTRESPONSE,
    serialized_options=b'\202\323\344\223\0027*5/apigateways/websocket/v1/connections/{connection_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CONNECTIONSERVICE)

DESCRIPTOR.services_by_name['ConnectionService'] = _CONNECTIONSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/iam_token_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/iam_token_service.proto',
  package='yandex.cloud.iam.v1',
  syntax='proto3',
  serialized_options=b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+yandex/cloud/iam/v1/iam_token_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"_\n\x15\x43reateIamTokenRequest\x12%\n\x1byandex_passport_oauth_token\x18\x01 \x01(\tH\x00\x12\r\n\x03jwt\x18\x02 \x01(\tH\x00\x42\x10\n\x08identity\x12\x04\xc0\xc1\x31\x01\"[\n\x16\x43reateIamTokenResponse\x12\x11\n\tiam_token\x18\x01 \x01(\t\x12.\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"R\n&CreateIamTokenForServiceAccountRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=502\xc8\x02\n\x0fIamTokenService\x12|\n\x06\x43reate\x12*.yandex.cloud.iam.v1.CreateIamTokenRequest\x1a+.yandex.cloud.iam.v1.CreateIamTokenResponse\"\x19\x82\xd3\xe4\x93\x02\x13\"\x0e/iam/v1/tokens:\x01*\x12\xb6\x01\n\x17\x43reateForServiceAccount\x12;.yandex.cloud.iam.v1.CreateIamTokenForServiceAccountRequest\x1a+.yandex.cloud.iam.v1.CreateIamTokenResponse\"1\x82\xd3\xe4\x93\x02+\"&/iam/v1/tokens:createForServiceAccount:\x01*BV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_CREATEIAMTOKENREQUEST = _descriptor.Descriptor(
  name='CreateIamTokenRequest',
  full_name='yandex.cloud.iam.v1.CreateIamTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='yandex_passport_oauth_token', full_name='yandex.cloud.iam.v1.CreateIamTokenRequest.yandex_passport_oauth_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jwt', full_name='yandex.cloud.iam.v1.CreateIamTokenRequest.jwt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='identity', full_name='yandex.cloud.iam.v1.CreateIamTokenRequest.identity',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=162,
  serialized_end=257,
)


_CREATEIAMTOKENRESPONSE = _descriptor.Descriptor(
  name='CreateIamTokenResponse',
  full_name='yandex.cloud.iam.v1.CreateIamTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='iam_token', full_name='yandex.cloud.iam.v1.CreateIamTokenResponse.iam_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='yandex.cloud.iam.v1.CreateIamTokenResponse.expires_at', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=259,
  serialized_end=350,
)


_CREATEIAMTOKENFORSERVICEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CreateIamTokenForServiceAccountRequest',
  full_name='yandex.cloud.iam.v1.CreateIamTokenForServiceAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.CreateIamTokenForServiceAccountRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=352,
  serialized_end=434,
)

_CREATEIAMTOKENREQUEST.oneofs_by_name['identity'].fields.append(
  _CREATEIAMTOKENREQUEST.fields_by_name['yandex_passport_oauth_token'])
_CREATEIAMTOKENREQUEST.fields_by_name['yandex_passport_oauth_token'].containing_oneof = _CREATEIAMTOKENREQUEST.oneofs_by_name['identity']
_CREATEIAMTOKENREQUEST.oneofs_by_name['identity'].fields.append(
  _CREATEIAMTOKENREQUEST.fields_by_name['jwt'])
_CREATEIAMTOKENREQUEST.fields_by_name['jwt'].containing_oneof = _CREATEIAMTOKENREQUEST.oneofs_by_name['identity']
_CREATEIAMTOKENRESPONSE.fields_by_name['expires_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['CreateIamTokenRequest'] = _CREATEIAMTOKENREQUEST
DESCRIPTOR.message_types_by_name['CreateIamTokenResponse'] = _CREATEIAMTOKENRESPONSE
DESCRIPTOR.message_types_by_name['CreateIamTokenForServiceAccountRequest'] = _CREATEIAMTOKENFORSERVICEACCOUNTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateIamTokenRequest = _reflection.GeneratedProtocolMessageType('CreateIamTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIAMTOKENREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.iam_token_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateIamTokenRequest)
  })
_sym_db.RegisterMessage(CreateIamTokenRequest)

CreateIamTokenResponse = _reflection.GeneratedProtocolMessageType('CreateIamTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIAMTOKENRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.iam_token_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateIamTokenResponse)
  })
_sym_db.RegisterMessage(CreateIamTokenResponse)

CreateIamTokenForServiceAccountRequest = _reflection.GeneratedProtocolMessageType('CreateIamTokenForServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEIAMTOKENFORSERVICEACCOUNTREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.iam_token_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.CreateIamTokenForServiceAccountRequest)
  })
_sym_db.RegisterMessage(CreateIamTokenForServiceAccountRequest)


DESCRIPTOR._options = None
_CREATEIAMTOKENREQUEST.oneofs_by_name['identity']._options = None
_CREATEIAMTOKENFORSERVICEACCOUNTREQUEST.fields_by_name['service_account_id']._options = None

_IAMTOKENSERVICE = _descriptor.ServiceDescriptor(
  name='IamTokenService',
  full_name='yandex.cloud.iam.v1.IamTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=437,
  serialized_end=765,
  methods=[
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iam.v1.IamTokenService.Create',
    index=0,
    containing_service=None,
    input_type=_CREATEIAMTOKENREQUEST,
    output_type=_CREATEIAMTOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002\023\"\016/iam/v1/tokens:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateForServiceAccount',
    full_name='yandex.cloud.iam.v1.IamTokenService.CreateForServiceAccount',
    index=1,
    containing_service=None,
    input_type=_CREATEIAMTOKENFORSERVICEACCOUNTREQUEST,
    output_type=_CREATEIAMTOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002+\"&/iam/v1/tokens:createForServiceAccount:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_IAMTOKENSERVICE)

DESCRIPTOR.services_by_name['IamTokenService'] = _IAMTOKENSERVICE

# @@protoc_insertion_point(module_scope)
